Draws a circular representative population chart based on group proportions, where each point (person) represents a fixed number of individuals. Each person is rendered as a Font Awesome icon.
Usage
geom_pop(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE,
icon = "ggmale",
group_var = NULL,
sample_size = NULL,
arrange = FALSE,
seed = NULL,
sum_var = NULL,
facet = NULL,
size = 1,
dpi = 50,
legend_icons = TRUE,
stroke_width = NULL,
...
)Arguments
- mapping
Set of aesthetic mappings created by
aes(). If specified andinherit.aes = TRUE(the default), it is combined with the default mapping at the top level of the plot. You must supplymappingif there is no plot mapping.- data
The data to be displayed in this layer. There are three options:
If
NULL, the default, the data is inherited from the plot data as specified in the call toggplot().A
data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. Seefortify()for which variables will be created.A
functionwill be called with a single argument, the plot data. The return value must be adata.frame, and will be used as the layer data. Afunctioncan be created from aformula(e.g.~ head(.x, 10)).- stat
The statistical transformation to use on the data for this layer. When using a
geom_*()function to construct a layer, thestatargument can be used to override the default coupling between geoms and stats. Thestatargument accepts the following:A
Statggproto subclass, for exampleStatCount.A string naming the stat. To give the stat as a string, strip the function name of the
stat_prefix. For example, to usestat_count(), give the stat as"count".For more information and other ways to specify the stat, see the layer stat documentation.
- position
A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The
positionargument accepts the following:The result of calling a position function, such as
position_jitter(). This method allows for passing extra arguments to the position.A string naming the position adjustment. To give the position as a string, strip the function name of the
position_prefix. For example, to useposition_jitter(), give the position as"jitter".For more information and other ways to specify the position, see the layer position documentation.
- na.rm
logical, whether remove NA values
- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.FALSEnever includes, andTRUEalways includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, useTRUE. IfNA, all levels are shown in legend, but unobserved levels are omitted.- inherit.aes
If
FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.annotation_borders().- icon
Default icon to use when no icon column is mapped.
- group_var
(Deprecated) Use
aes(group = ...)instead.- sample_size
The total number of individuals (points) to draw.
- arrange
Logical; if TRUE, output data is arranged by group.
- seed
Optional numeric seed used only when
arrange = FALSE.- sum_var
Optional variable to sum over instead of counting.
- facet
Optional faceting variable. If provided, final plot must be faceted with ggplot2 (use
validate_geom_pop_faceting(p)).- size
Icon size. If mapped in
aes(size = ...)the parameter is ignored.- dpi
Height (in pixels) of the rendered PNG when using
fontawesome::fa_png(). Higher values produce sharper icons.- legend_icons
Logical; if TRUE, legend displays the selected icons.
- stroke_width
Numeric. Width of the icon outline in pixels (single value).
- ...
additional parameters
Aesthetics
geom_pop understands the following aesthetics:
icon: Font Awesome icon name (mapped column)
group: grouping variable for raw data mode
color/colour: icon color
alpha: transparency (must be mapped)
size: icon size (mapped or fixed)