Legend helper for geom_pop/geom_icon_point legends
Source:R/scale_legend_icon.R
scale_legend_icon.RdA convenience function to set appropriate legend key sizes for icon-based legends. This is equivalent to using theme(legend.key.size = ...) but provides sensible defaults for population icon plots.
Arguments
- size
Numeric. Legend key size in specified units (default 10).
- unit
Character. Unit for legend key sizing (default "mm").
- spacing
Numeric. Spacing between legend items as fraction of size (default 0.2).
- size_multiplier
Numeric. Multiplier to apply to the size for spacing calculations (default 2).
- ...
Additional theme arguments.